@@ -17,35 +17,37 @@
 
 #mode=1 model.matrix
 #mode=2 model.frame
-multilevel<-function(tt,data,mode,...){
+multilevel<-function(tt,data,mode,eqn,...){
   if(!(mode %in% c(1,2)))
     stop("Wrong mode argument")
+  if(is.null(eqn))
+    stop("Please provide an equations")
 res<-list()
-  eqn<-attr(tt,"systEqns")
+  eqns<-attr(tt,"systEqns")
   subs<-attr(tt,"subs")
 depVars<-attr(tt,"depVars")
 
-  nrEquations<-length(eqn)
+  nrEquations<-length(eqns)
   termlabels<-attr(tt,"term.labels")
-for(i in 1:nrEquations){
-  rhs<-toBuildFormula(termlabels[[eqn[[i]]]],"+")
+#for(i in 1:nrEquations){
+  rhs<-toBuildFormula(termlabels[[eqn]],"+")
   if(!is.null(rhs))
     rhs<-paste("~",rhs)
   else
     rhs<-"~1"
-  Ynamei<-depVars[[eqn[[i]]]]
+  Ynamei<-depVars[[eqn]]
   if(!(Ynamei %in% colnames(subs)))
     lhs<-Ynamei
   else
     lhs<-NULL
   f<-as.formula(paste(lhs,rhs))
   if(mode==1)
-    res[[eqn[[i]]]]<-model.matrix.default(f,data[[eqn[[i]]]])
-  #    res[[eqn[[i]]]]<-f
+    res<-model.matrix.default(f,data)
+  #    res[[eqns[[i]]]]<-f
   else
-    res[[eqn[[i]]]]<-model.frame.default(f,data[[eqn[[i]]]])
- # res[[eqn[[i]]]]<-f
-}
+    res<-model.frame.default(f,data)
+ # res[[eqns[[i]]]]<-f
+#}
 attr(res,"terms")<-tt
 return(res)
 }
