@@ -1,12 +1,15 @@
 summary.lm.robust <- function(object, ...) {
   class(object) <- "lm"
   res <- summary.lm(object, ...)
-  if (is.null(object$robust))
+  if (is.null(object$robust)) {
     res$cov.unscaled <- R <- vcovHC(object)/(res$sigma^2)
+    res$robust <- "vcovHC"
+  }
   else {
     fn <- object$robust$method
+    res$robust <- object$robust$method
     object$robust$method <- NULL
-    arg <- object$list
+    arg <- object$robust
     arg$x <- object
     res$cov.unscaled <- R <- eval(do.call(fn, arg))/(res$sigma^2)
   }
@@ -16,6 +19,8 @@ summary.lm.robust <- function(object, ...) {
     dimnames(res$correlation) <- dimnames(res$cov.unscaled)
   }
   res$coefficients[,3] <- tval <- coefficients(object)/se
-  res$coefficients[,4] <- 2*pt(abs(tval), res$df[2], lower.tail = FALSE)
+  res$coefficients[,4] <- 2*pt(abs(tval), res$df[2], lower.tail =
+                               FALSE)
+  class(res) <- c("summary.lm.robust", "summary.lm")
   return(res)
 }
